==> haskell-hls-floskell-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-FEfWQjHqxTRG26oqLxJq2U
key:                  hls-floskell-plugin-2.1.0.0-FEfWQjHqxTRG26oqLxJq2U
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0e6543d39b0666f48f3c2229125ff12b
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-FEfWQjHqxTRG26oqLxJq2U
depends:
    base-4.17.2.1 floskell-0.10.8-JEVMs0AUcMVCRjfwmuMeF9
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-floskell-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-IwNPMWzWdLfJp1KExYB1N9
key:                  hls-floskell-plugin-2.1.0.0-IwNPMWzWdLfJp1KExYB1N9
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  83b39c5ac833c1623dfc78b4b3adf528
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-IwNPMWzWdLfJp1KExYB1N9
depends:
    base-4.17.2.1 floskell-0.10.8-6YzWTESlxP3BA3k1vGfBjs
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
